<pre>
        _   _     _                 
       | | (_)   | |                
   ___ | |  _  __| | ___  _ __ ___  
  / __|| | | |/ _` |/ _ \| '__/ _ \ 
 | (__ | | | | (_| | (_) | | | (_) |
  \___||_| |_|\__,_|\___/|_|  \___/ 
</pre>


Motivation: I really loved Habitica's Pomodoro because I could keep track of info, but sometimes it deletes all data, and if I don't have a backup, I am done for. Anyway, I use the terminal a lot, and this seems like a much better option to me than Habitica's Chrome extension. I have used my own tool for over a week now. Sharing this anyway, even though I don't know if anyone would want to use a Pomodoro on CLI. I have some features like sound, history, and all. Will improve later when I have time. You could also contribute if you want to, and I appreciate that. 

Demo (sorry for the bad quality lol):

![Alt Text](/assets/clidoro.gif)

To install Do `pip install clidoro`. Then just type `clidoro` whenever you want.

**For Devs**: To install: Clone the repo and do a `pip install -e .`. Then just type `clidoro` whenever you want.



TODO:
- [ ] add windows support (not tested)
- [ ] add mac support (not tested)
- [x] pypi
- [ ] background sound
- [ ] custom notification sound (use my [data-server](https://github.com/kingjuno/data-server))
- [x] Desktop Notification popup
- [x] Clear Database